@@ -5,6 +5,8 @@
 */
 
 #include "transportmanager.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "mailtransport_defs.h"
 #include "plugins/transportabstractplugin.h"
 #include "plugins/transportpluginmanager.h"
@@ -383,7 +385,7 @@ void TransportManagerPrivate::readConfig()
         Transport *t = nullptr;
         // see if we happen to have that one already
         const QString capturedString = match.captured(1);
-        const QString checkString = QLatin1String("Transport ") + capturedString;
+        const QString checkString = "Transport "_L1 + capturedString;
         for (Transport *old : oldTransports) {
             if (old->currentGroup() == checkString) {
                 qCDebug(MAILTRANSPORT_LOG) << "reloading existing transport:" << s;
